#include <windows.h> 
#include "gpioLib.h"
#include "CoProcLib.h"
#include "PWMLib.h"

int wmain()
{
    DWORD procID = 0;
    DWORD verMaj = 0;
    DWORD verMin = 0;
    DWORD pwmPin = 30;       ///< PWM signal on SODIMM_30
    DWORD pwmMenu = 0;
    DWORD pwmDuty = 0;
    DWORD pwmScale = 0;
    DWORD verBuild = 0;
    DWORD pwmPeriod = 0;
    DWORD pwmChannel = 0;

    InitGPIOLib();           ///< Initialize GPIO library
    GPIOGetLibVersion(&verMaj, &verMin, &verBuild);
    printf("\nGPIOLib Version %d.%d.%d", verMaj, verMin, verBuild);
    PWMGetLibVersion(&verMaj, &verMin, &verBuild);
    printf("\nPWMLib Version %d.%d.%d", verMaj, verMin, verBuild);

    procID = getPROCID();                              ///< Get processor ID
    if (procID == TYPE_TEGRA2 || procID == TYPE_TEGRA3)
    {
        printf("\nTegra detected\n");
        SetPinAltFn(pwmPin, 1, DIR_OUT);               ///< Set Pin functionality as PWM and set to Output
        pwmChannel = 2;                                ///< PWM channel 2 
        printf("\nEnter prescale (1 - 8192):");
        scanf_s("%d", &pwmScale);
        InitPWM(pwmChannel, pwmScale, 256);            ///< Initialize PWM controller channel 2, period = 256
    }
    else if (procID == TYPE_PXA270 || procID == TYPE_PXA300 || procID == TYPE_PXA310 || procID == TYPE_PXA320)
    {
        printf("\nPXA detected\n");
        if (procID == TYPE_PXA270)
        {
            SetPinAltFn(pwmPin, 2, DIR_OUT);           ///< Set Pin functionality as PWM and set to Output 
        }
        else
        {
            SetPinAltFn(pwmPin, 1, DIR_OUT);           ///< Set Pin functionality as PWM and set to Output
        }
        pwmChannel = 0;                                ///< PWM channel 0
        printf("\nPeriod (1 - 1024)\t:");
        scanf_s("%d", &pwmPeriod);
        printf("\nPreScale (1 - 64)\t:"); 
        scanf_s("%d", &pwmScale);  
        InitPWM(pwmChannel, pwmScale, pwmPeriod);      ///< Initialize PWM controller channel 0
    }
    while (pwmMenu != 1)
    {
        printf("\nDuty (1-100)\t:"); 
        scanf_s("%d", &pwmDuty);
        SetPWMDutyPercentage(pwmChannel, pwmDuty);     ///< Assign percentage duty cycle in PWM controller 
        printf("\nExit (1)\t:"); 
        scanf_s("%d", &pwmMenu);
     }

    printf("\nPress Enter to end the program\n");
    getchar();
    DeInitPWM(pwmChannel);   ///< De-initialize PWM controller
    DeInitGPIOLib();         ///< Release resources used by GPIO library and de-initialize GPIO library function
    return TRUE;
}